@@ -7,16 +7,19 @@ sentry.processors.base
 """
 import logging
 
+from django.db import transaction
+
 from sentry.plugins import plugins
 
 __all__ = ('send_group_processors',)
 
 
-def send_group_processors(**kwargs):
+def send_group_processors(group, **kwargs):
     for inst in plugins.all():
         try:
-            inst.post_process(**kwargs)
+            inst.post_process(group=group, **kwargs)
         except:
+            transaction.rollback_unless_managed(using=group._state.db)
             logger = logging.getLogger('sentry.plugins')
             logger.exception('Error processing post_process() on %r', inst.__class__)
 
